@@ -9,7 +9,10 @@ class PathOptions:
     shared_library_folder_name = "lib"
 
     # extend the below list if there are new types of shared libraries
-    _shared_library_file_patterns = [r".+\.so(\.\d{1,})?$", r".+\.dylib$"]
+    # below patterns should match (but not limited to):
+    #  filename.so, filename.so.12, filename.so.debug
+    #  filename.dylib
+    _shared_library_file_patterns = [r".+\.so(\.(\d{1,}|debug))?$", r".+\.dylib$"]
     _compiled_shared_library_file_patterns = None
 
     @property
