@@ -86,7 +86,7 @@ def get_buildvariant_name(edition, platform, architecture, major_minor_version):
             and buildvariant.architecture == architecture
         ):
             versions = buildvariant.versions
-            if major_minor_version in versions:
+            if versions is not None and major_minor_version in versions:
                 buildvariant_name = buildvariant.name
                 break
             elif not versions:
@@ -217,22 +217,17 @@ def _filter_successful_tasks(evg_tasks) -> _MultiversionTasks:
     binary_task = None
     symbols_task = None
     push_task = None
+
+    targeted_tasks = SETUP_REPRO_ENV_CONFIG.evergreen_tasks
     for evg_task in evg_tasks:
-        if (
-            binary_task is None
-            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.binary
-        ):
+        if binary_task is None and targeted_tasks.is_task_binary(evg_task):
             binary_task = evg_task
-        if (
-            push_task is None
-            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.push
-        ):
+        if push_task is None and targeted_tasks.is_task_push(evg_task):
             push_task = evg_task
-        if (
-            symbols_task is None
-            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.symbols
-        ):
+        if symbols_task is None and targeted_tasks.is_task_symbols(evg_task):
             symbols_task = evg_task
+
         if binary_task and push_task and symbols_task:
             break
+
     return _MultiversionTasks(symbols=symbols_task, binary=binary_task, push=push_task)
